pub struct RcuReadLease<T> { /* private fields */ }Expand description
Reader-held fractional permission split from an RcuLeaseAccumulator.
Implementations
Sourceimpl<T> RcuReadLease<T>
impl<T> RcuReadLease<T>
Sourcepub proof fn tracked_borrow(tracked &self) -> tracked resource : &T
pub proof fn tracked_borrow(tracked &self) -> tracked resource : &T
ensures
*resource == self.resource(),Borrows the protected resource for the lifetime of this lease borrow.
Sourcepub proof fn lemma_fraction_bounded(tracked &self)
pub proof fn lemma_fraction_bounded(tracked &self)
ensures
0real < self.fraction() <= 1real,Establishes that every lease carries a positive rational fraction.